package bicliqueviz;

/**
 * 
 * With this class you can represent a given biclique in a bipartite graph.
 * Each biclique instance is represented by an biclique ID an array of
 * vertex A IDs and an array of vertex B IDs and what type or size biclique
 * it is (for example k=2,2). 
 * 
 * @author Martin Schwartz
 *
 */
public class Biclique 
{
	private int id;
	private int[] upper;
	private int[] lower;
	private String bicliqueType;

	/**
	 * @param i biclique ID
	 * @param u array of vertex A IDs
	 * @param l array of vertex B IDs
	 * @param bt type of biclique (should have the following format: "k=a,b")
	 */
	public Biclique(int i, int[] u, int[] l, String bt) 
	{
		id = i;
		upper = u;
		lower = l;
		bicliqueType = bt;
	}
	
	/**
	 * @return biclique ID
	 */
	public int getID()
	{
		return id;
	}
	
	/**
	 * @return array of vertex A IDs
	 */
	public int[] getBicliqueUpper()
	{
		return upper;
	}
	
	/**
	 * @return array of vertex B IDs
	 */
	public int[] getBicliqueLower()
	{
		return lower;
	}
	
	public String toString()
	{
		return id +". biclique ("+bicliqueType+")";
	}

}
