package bicliqueviz;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

public class CommandLineBCF 
{
	private CommandTree tree;
	private InfoFile infoFile;
	public final static int MAX_HISTOGRAM_SIZE = 15;
	public static int[][] histogramMatrix;
	public static int maxHistogramValue;

	public CommandLineBCF() 
	{
		histogramMatrix = new int[MAX_HISTOGRAM_SIZE][MAX_HISTOGRAM_SIZE];
		
		for(int i = 0; i < MAX_HISTOGRAM_SIZE; i++)
		{
			for(int j = 0; j < MAX_HISTOGRAM_SIZE; j++)
			{
				histogramMatrix[i][j] = 0;
			}
		}
		maxHistogramValue = 0;
	}

	
	/**
	 * @param args -o(i)(t) <file> <idA> <idB> <minA> <minB> <maxA> <maxB>
	 */
	public void runBCF(String[] args)
	{
		if(args[0].startsWith("-"))
		{
			if(args[0].startsWith("-o"))
			{
				long t1 = System.currentTimeMillis();
				int argsIndex = 1;
				File f = new File(args[argsIndex]);
				String fileName = f.getPath();
				argsIndex++;
				String idFileA = null;
				String idFileB = null;
				
				File cacheDir = new File(fileName+"_files");
				
				if(args[0].startsWith("-oi"))
				{
					idFileA = !cacheDir.exists() ? args[argsIndex] : null;
					argsIndex++;
					idFileB = !cacheDir.exists() ? args[argsIndex] : null;
					argsIndex++;
				}
				
				String minThresA = "1";
				String minThresB = "1";
				String maxThresA = String.valueOf(Integer.MAX_VALUE);
				String maxThresB = String.valueOf(Integer.MAX_VALUE);
				
				if(args[0].startsWith("-oit"))
				{
					minThresA = !cacheDir.exists() ? args[argsIndex] : "1";
					argsIndex++;
					minThresB = !cacheDir.exists() ? args[argsIndex] : "1";
					argsIndex++;
					maxThresA = !cacheDir.exists() ? args[argsIndex] : null;
					maxThresA = maxThresA.equals("-1") ? String.valueOf(Integer.MAX_VALUE) : maxThresA;
					argsIndex++;
					maxThresB = !cacheDir.exists() ? args[argsIndex] : null;
					maxThresB = maxThresB.equals("-1") ? String.valueOf(Integer.MAX_VALUE) : maxThresB;
					argsIndex++;
				}
				
				String name = fileName;
				int index = name.lastIndexOf(".");
				if(index > 0)
				{
					name = name.substring(0, index);
				}
				String size = name+".sz";
				
				if(cacheDir.exists())
				{
					
				}
				else
				{
					String bigraph = name+".bi";
					
					LCM.runLCM(null, fileName, bigraph, size, Integer.parseInt(minThresA), Integer.parseInt(minThresB), 
							Integer.parseInt(maxThresA), Integer.parseInt(maxThresB), true);
					
					tree = new CommandTree(size, bigraph, Integer.parseInt(minThresA), Integer.parseInt(minThresB),
							Integer.parseInt(maxThresA), Integer.parseInt(maxThresB));
					
					tree.createOverlapMatrix2();
					infoFile = new InfoFile(idFileA, idFileB, null);
					tree.createTree(infoFile);
					
					CacheFilesSaver cfm = new CacheFilesSaver(fileName, tree.getChildren(), tree.getCommunitiesTree(), tree.getBicliques(), infoFile);
					cfm.createCacheFiles();
				}
				
				createHistogramMatrix(size);
				
				long t2 = System.currentTimeMillis();
				
				if(tree != null)
				{
					System.out.println();
					System.out.println("Time elapsed: "+ (t2-t1));
				}
			}
		}
	}
	
	private void createHistogramMatrix(String sz)
	{
		try 
		{
			BufferedReader reader = new BufferedReader(new FileReader(sz));
			
			String line = reader.readLine();
			
			while(line != null)
			{
				String[] splitLine = line.split("\\s");
				int a = Integer.parseInt(splitLine[0]);
				int b = Integer.parseInt(splitLine[1]);
				
				if(a > MAX_HISTOGRAM_SIZE)
				{
					a = MAX_HISTOGRAM_SIZE;
				}
				if(b > MAX_HISTOGRAM_SIZE)
				{
					b = MAX_HISTOGRAM_SIZE;
				}
				histogramMatrix[a-1][b-1]++;
				
				maxHistogramValue = Math.max(maxHistogramValue, histogramMatrix[a-1][b-1]);
				line = reader.readLine();
			}
		} 
		catch (FileNotFoundException e) 
		{
			e.printStackTrace();
		} 
		catch (IOException e) 
		{
			e.printStackTrace();
		}
	}
}
