/*
* Copyright (c) 2003, the JUNG Project and the Regents of the University 
* of California
* All rights reserved.
*
* This software is open-source under the BSD license; see either
* "license.txt" or
* http://jung.sourceforge.net/license.txt for a description.
*/
package bicliqueviz;

import edu.uci.ics.jung.visualization.*;
import java.awt.Dimension;
import java.awt.event.MouseEvent;
import java.awt.geom.Point2D;

import edu.uci.ics.jung.algorithms.layout.Layout;

/**
 * Adds mouse behaviors and tooltips to the graph visualization base class
 * 
 * @author Joshua O'Madadhain
 * @author Tom Nelson 
 * @author Danyel Fisher
 */
@SuppressWarnings("serial")
public class CustomVV<V,E> extends VisualizationViewer<V,E> 
{
	private boolean toolTipOn = false;
	
	public CustomVV(Layout<V,E> layout) {
	    this(new DefaultVisualizationModel<V,E>(layout));
	}
	
	/**
	 * 
	 * Create an instance with passed parameters.
	 * 
	 * @param layout The Layout to apply, with its associated Graph
	 * @param preferredSize the preferred size of this View
	 */
	public CustomVV(Layout<V,E> layout, Dimension preferredSize) {
	    this(new DefaultVisualizationModel<V,E>(layout, preferredSize), preferredSize);
	}
	
	/**
	 * 
	 * Create an instance with passed parameters.
	 * 
	 * @param model
	 */
	public CustomVV(VisualizationModel<V,E> model) {
	    this(model, new Dimension(600,600));
	}	
	
	/**
	 * 
	 * Create an instance with passed parameters.
	 * 
	 * @param model
	 * @param preferredSize initial preferred size of the view
	 */
	@SuppressWarnings("unchecked")
    public CustomVV(VisualizationModel<V,E> model,
	        Dimension preferredSize) {
        super(model, preferredSize);
		setFocusable(true);
        addMouseListener(requestFocusListener);
	}
	
	public boolean getToolTipOn()
	{
		return toolTipOn;
	}

    /**
     * called by the superclass to display tooltips
     */
    public String getToolTipText(MouseEvent event) 
    {
        Layout<V,E> layout = getGraphLayout();
        Point2D p = null;
        if(vertexToolTipTransformer != null) {
            p = event.getPoint();
            	//renderContext.getBasicTransformer().inverseViewTransform(event.getPoint());
            toolTipOn = true;
            V vertex = getPickSupport().getVertex(layout, p.getX(), p.getY());
            toolTipOn = false;
            if(vertex != null) {
            	return vertexToolTipTransformer.transform(vertex);
            }
        }
        if(edgeToolTipTransformer != null) {
        	if(p == null) p = renderContext.getMultiLayerTransformer().inverseTransform(Layer.VIEW, event.getPoint());
            E edge = getPickSupport().getEdge(layout, p.getX(), p.getY());
            if(edge != null) {
            	return edgeToolTipTransformer.transform(edge);
            }
        }
        if(mouseEventToolTipTransformer != null) {
        	return mouseEventToolTipTransformer.transform(event);
        }
        return super.getToolTipText(event);
    }
}
