package bicliqueviz;

import java.awt.Shape;
import java.awt.Paint;
import java.awt.Color;
import java.awt.Stroke;
import java.awt.geom.AffineTransform;
import java.awt.geom.Point2D;
import javax.swing.Icon;
import edu.uci.ics.jung.visualization.RenderContext;
import edu.uci.ics.jung.visualization.Layer;
import edu.uci.ics.jung.visualization.renderers.BasicVertexRenderer;
import edu.uci.ics.jung.algorithms.layout.Layout;
import edu.uci.ics.jung.visualization.transform.shape.GraphicsDecorator;

/**
 * 
 * Class for custom vertex rendering
 * 
 * @author Martin Schwartz
 *
 */
public class CustomVertexRenderer extends BasicVertexRenderer<VertexObj, EdgeObj>
{
	protected void paintIconForVertex(RenderContext<VertexObj, EdgeObj> rc, VertexObj v, Layout<VertexObj, EdgeObj> layout) 
	{
        GraphicsDecorator g = rc.getGraphicsContext();
        boolean vertexHit = true;
        // get the shape to be rendered
        Shape shape = rc.getVertexShapeTransformer().transform(v);
        
        Point2D p = layout.transform(v);
        p = rc.getMultiLayerTransformer().transform(Layer.LAYOUT, p);
        float x = (float)p.getX();
        float y = (float)p.getY();
        // create a transform that translates to the location of
        // the vertex to be rendered
        AffineTransform xform = AffineTransform.getTranslateInstance(x,y);
        // transform the vertex shape with xtransform
        shape = xform.createTransformedShape(shape);
        
        vertexHit = vertexHit(rc, shape);
            //rc.getViewTransformer().transform(shape).intersects(deviceRectangle);

        if (vertexHit) 
        {
        	if(rc.getVertexIconTransformer() != null) 
        	{
        		Icon icon = rc.getVertexIconTransformer().transform(v);
        		if(icon != null) 
        		{
        			int xLoc = (int) (x - icon.getIconWidth()/2);
        			int yLoc = (int) (y - icon.getIconHeight()/2);
        			icon.paintIcon(rc.getScreenDevice(), g.getDelegate(), xLoc, yLoc);
        		} 
        		else 
        		{
        			paintShapeForVertex(rc, v, shape, x-v.getCommunityVertexSize()/2, y-v.getCommunityVertexSize()/2);
        		}
        	} 
        	else 
        	{
        		paintShapeForVertex(rc, v, shape, x-v.getCommunityVertexSize()/2, y-v.getCommunityVertexSize()/2);
        	}
        }
    }
	
	protected void paintShapeForVertex(RenderContext<VertexObj, EdgeObj> rc, VertexObj v, Shape shape, double x, double y) 
	{
        GraphicsDecorator g = rc.getGraphicsContext();
        Paint oldPaint = g.getPaint();
        Paint fillPaint = rc.getVertexFillPaintTransformer().transform(v);
        if(fillPaint != null) 
        {
            g.setPaint(fillPaint);
            g.fill(shape);
            drawPie(g,x,y,v);
            g.setPaint(oldPaint);
        }
        Paint drawPaint = rc.getVertexDrawPaintTransformer().transform(v);
        if(drawPaint != null) 
        {
            g.setPaint(drawPaint);
        }
        Stroke oldStroke = g.getStroke();
        Stroke stroke = rc.getVertexStrokeTransformer().transform(v);
        if(stroke != null) 
        {
            g.setStroke(stroke);
        }
        g.draw(shape);
        g.setPaint(oldPaint);
        g.setStroke(oldStroke);
    }
	
	private void drawPie(GraphicsDecorator g, double x, double y, VertexObj v) 
	{
        // Get total value of all slices
        double total = 0.0D;
        for (int i=0; i<2; i++) 
        {
            total += v.getNodePercent(i);
        }
    
        // Draw each pie slice
        double curValue = 0.0D;
        int startAngle = 0;
        Color[] colours = {Color.RED,Color.BLUE};
        for (int i=0; i<2; i++) 
        {
            // Compute the start and stop angles
            startAngle = (int)(curValue * 360 / total);
            int arcAngle = (int)(v.getNodePercent(i) * 360 / total);
    
            // Ensure that rounding errors do not leave a gap between the first and last slice
            if (i == 2-1) 
            {
                arcAngle = 360 - startAngle;
            }
    
            // Set the color and draw a filled arc
            g.setColor(colours[i]);
            g.fillArc((int)x, (int)y, v.getCommunityVertexSize(), v.getCommunityVertexSize(), startAngle, arcAngle);
    
            curValue += v.getNodePercent(i);
        }
    }
}
