package bicliqueviz;

import java.awt.Color;

/**
 * 
 * This class represent the edges in the JUNG graph
 * 
 * @author Martin Schwartz
 *
 */
public class EdgeObj 
{
	private String vertexA;
	private String vertexB;
	private float thickness = 1.0f;
	private int nodeOverlap;
	private Color fill = new Color(0,0,0);
	
	/**
	 * @param aName name of vertex A
	 * @param bName name of vertex B
	 * @param a id of vertex A
	 * @param b if of vertex B
	 */
	public EdgeObj(String aName, String bName, int a, int b) 
	{
		if(aName != null)
		{
			vertexA = aName;
		}
		else
		{
			vertexA = a+"";
		}
		if(bName != null)
		{
			vertexB = bName;
		}
		else
		{
			vertexB = b+"";
		}
		nodeOverlap = 0;
	}
	
	/**
	 * @param aName name of vertex A
	 * @param bName name of vertex B
	 * @param a id of vertex A
	 * @param b id of vertex B
	 * @param t thickness of edge
	 * @param f colour of edge
	 */
	public EdgeObj(String aName, String bName, int a, int b, Float t, Color f) 
	{
		if(aName != null)
		{
			vertexA = aName;
		}
		else
		{
			vertexA = a+"";
		}
		if(bName != null)
		{
			vertexB = bName;
		}
		else
		{
			vertexB = b+"";
		}
		if(t != null)
		{
			thickness = t;
		}
		if(f != null)
		{
			fill = f;
		}
		
		nodeOverlap = 0;
	}
	
	public boolean equals(Object o)
	{
		if(o != null && o.getClass().equals(EdgeObj.class))
		{
			return o.toString().equals(this.toString());
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * @param t value of new thickness
	 */
	public void setThickness(float t)
	{
		thickness = t;
	}
	
	/**
	 * @param no new value for node overlap
	 */
	public void setNodeOverlap(int no)
	{
		nodeOverlap = no;
	}
	
	/**
	 * @return number of overlapping nodes
	 */
	public int getNodeOverlap()
	{
		return nodeOverlap;
	}
	
	/**
	 * @return thickness of edge
	 */
	public float getThickness()
	{
		return thickness;
	}
	
	/**
	 * @param f new colour for the edge
	 */
	public void setFill(Color f)
	{
		fill = f;
	}
	
	/**
	 * @return the colour of the edge
	 */
	public Color getFill()
	{
		return fill;
	}
	
	public int hashCode()
	{
		return this.toString().hashCode();
	}
	
	public String toString()
	{
		return vertexA +" --- "+ vertexB;
	}

}
