package bicliqueviz;

import java.awt.Color;

/**
 * 
 * Class for representing the vertices in the graph
 * 
 * @author the1schwartz
 *
 */
public class VertexObj 
{
	private int vertexID;
	boolean vertexA;
	private String name;
	private int numOfCliqueOccurs;
	private Color colour;
	private String shape;
	private Double[] nodePercent;
	private int numOfNodes[];
	
	/**
	 * @param n name of vertex
	 * @param id id of vertex
	 * @param a true if the vertex is type A else false
	 * @param c colour of the vertex
	 * @param s string defining the shape of the vertex (can be SQUARE or TRIANGLE)
	 */
	public VertexObj(String n, int id, boolean a, Color c, String s) 
	{
		if(n != null)
		{
			name = n;
		}
		else
		{
			name = id+"";
		}
		
		if(c == null && a)
		{
			colour = Color.RED;
		}
		else if(c == null && !a)
		{
			colour = Color.BLUE;
		}
		else
		{
			colour = c;
		}
		
		shape = s;
			
		vertexID = id;
		vertexA = a;
		numOfCliqueOccurs = 0;
		nodePercent = new Double[2];
		nodePercent[0] = null;
		nodePercent[1] = null;
		numOfNodes = new int[2];
		numOfNodes[0] = 0;
		numOfNodes[1] = 0;
	}
	
	/**
	 * @param up value for percentage of type A
	 */
	public void setUpperPercent(Double up)
	{
		nodePercent[0] = up;
	}
	
	/**
	 * @param lp value for persentage of type B
	 */
	public void setLowerPercent(Double lp)
	{
		nodePercent[1] = lp;
	}
	
	/**
	 * @param i 0 for type A and 1 for type 1
	 * @return node percentage
	 */
	public Double getNodePercent(int i)
	{
		return nodePercent[i];
	}
	
	/**
	 * @param n number of type A nodes
	 */
	public void setNumOfUpperNodes(int n)
	{
		numOfNodes[0] = n;
	}
	
	/**
	 * @param n number of type B nodes
	 */
	public void setNumOfLowerNodes(int n)
	{
		numOfNodes[1] = n;
	}
	
	/**
	 * @param i 0 for type A and 1 for type 1
	 * @return number of nodes (type A or B)
	 */
	public int getNumOfNodes(int i)
	{
		return numOfNodes[i];
	}
	
	/**
	 * @return number of total nodes
	 */
	public int getNumOfNodes()
	{
		return numOfNodes[0] + numOfNodes[1];
	}
	
	/**
	 * @return size scale of community (how big it should be drawn)
	 */
	public int getCommunityVertexSize()
	{
		return (int)(CommunitySizeShape.SCALER*(float)getNumOfNodes())+20;
	}
	
	/**
	 * @return the string defining the shape
	 */
	public String getShape()
	{
		return shape;
	}
	
	/**
	 * @return the colour of the vertex
	 */
	public Color getColor()
	{
		return colour;
	}
	
	/**
	 * @return the name of the vertex
	 */
	public String getName()
	{
		return name;
	}
	
	/**
	 * @return the ID of the vertex
	 */
	public int getID()
	{
		return vertexID;
	}
	
	/**
	 * @return true if the vertex is of type A else false
	 */
	public boolean isVertexA()
	{
		return vertexA;
	}
	
	/**
	 * @param i number of clique occurences
	 */
	public void setCliqueOccurs(int i)
	{
		numOfCliqueOccurs = i;
	}
	
	/**
	 * @return the number of clique occurences
	 */
	public int getNumOfCliqueOccurs()
	{
		return numOfCliqueOccurs;
	}
	
	public int hashCode()
	{
		if(vertexA)
		{
			return vertexID;
		}
		else
		{
			return -vertexID;
		}
	}
	
	public boolean equals(Object o)
	{
		if(o != null && o.getClass().equals(VertexObj.class))
		{	
			VertexObj v = (VertexObj)o;
			return v.toString().equals(this.toString()) && v.isVertexA() == this.isVertexA();
		}
		else
		{
			return false;
		}
	}
	
	public String toString()
	{
		return name;
	}

}
