package bicliqueviz;

import java.awt.Shape;
import org.apache.commons.collections15.Transformer;
import edu.uci.ics.jung.visualization.decorators.AbstractVertexShapeTransformer;

/**
 * 
 * Class for vertex shape and size in the graph
 * 
 * @author the1schwartz
 *
 */
public class VertexSizeShape extends AbstractVertexShapeTransformer<VertexObj> implements Transformer<VertexObj,Shape>
{
	private BiGraph graph;
	private boolean scale = false;
	private int DOWN_SCALER = 3;

	public VertexSizeShape(BiGraph g) 
	{
		graph = g;
		setSizeTransformer(new Transformer<VertexObj,Integer>()
				{
					public Integer transform(VertexObj v) 
					{
						if(scale)
						{
							IDNodeTypePair p = new IDNodeTypePair(v.getID(),v.isVertexA());
							
							return graph.getInfoFile().get(p).getNumOfCliqueOccurs()/DOWN_SCALER+19;
						}
						else
						{
							return 20;
						}
					}
				});
	}
	
	/**
	 * @param scale toggles scaling on/off
	 */
	public void setScaling(boolean scale)
    {
        this.scale = scale;
    }
	
	/**
	 * @param d the scale factor the nodes
	 */
	public void setScaleSize(int d)
    {
		DOWN_SCALER = d;
    }
	
	public Shape transform(VertexObj v)
	{
		if(v.getShape() != null)
		{
			if(v.getShape().equalsIgnoreCase("SQUARE"))
			{
				return factory.getRectangle(v);
			}
			else if(v.getShape().equalsIgnoreCase("TRIANGLE"))
			{
				return factory.getRegularPolygon(v, 3);
			}
			else
			{
				return factory.getEllipse(v);
			}
		}
		else
		{
			return factory.getEllipse(v);
		}
	}

}
